@@ -119,7 +119,9 @@ fn deprecated_split_front_matter(content: &str) -> (Option<&str>, &str) {
                 .unwrap()
         });
     if FRONT_MATTER_DIVIDE.is_match(content) {
-        log::warn!("Trailing separators are deprecated. We recommend frontmatters be surrounded, above and below, with ---");
+        log::warn!(
+            "Trailing separators are deprecated. We recommend frontmatters be surrounded, above and below, with ---"
+        );
 
         let mut splits = FRONT_MATTER_DIVIDE.splitn(content, 2);
 
@@ -187,7 +189,7 @@ mod test {
     fn split_document_no_new_line_after_front_matter() {
         let input = "invalid_front_matter---\nbody";
         let (cobalt_model, content) = split_document(input);
-        println!("{:?}", cobalt_model);
+        println!("{cobalt_model:?}");
         assert!(cobalt_model.is_none());
         assert_eq!(content, input);
     }
@@ -196,7 +198,7 @@ mod test {
     fn split_document_multiline_body() {
         let input = "---\ncobalt_model\n---\nfirst\nsecond";
         let (cobalt_model, content) = split_document(input);
-        println!("{:?}", cobalt_model);
+        println!("{cobalt_model:?}");
         assert_eq!(cobalt_model.unwrap(), "cobalt_model\n");
         assert_eq!(content, "first\nsecond");
     }
