@@ -1,4 +1,7 @@
 #![cfg_attr(docsrs, feature(doc_auto_cfg))]
+#![warn(clippy::print_stderr)]
+#![warn(clippy::print_stdout)]
+#![allow(clippy::self_named_module_files)] // false positive
 
 mod assets;
 mod collection;
