@@ -1,6 +1,8 @@
 //! Markdown Fenced Code Block Highlighting
 
 #![cfg_attr(docsrs, feature(doc_auto_cfg))]
+#![warn(clippy::print_stderr)]
+#![warn(clippy::print_stdout)]
 
 #[cfg(feature = "syntax")]
 mod syntax;
